@@ -1,4 +1,4 @@
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 # All rights reserved.
 #
 # This source code is licensed under the BSD-style license found in the
@@ -8,9 +8,10 @@
 NULL
 
 .dbIsValid <- function(dbObj, ...) {
-  return(!dbObj@cursor$state() %in% c('__KILLED', 'FAILED'))
+  return(!dbObj@query$state() %in% c("__KILLED", "FAILED"))
 }
 
 #' @rdname PrestoResult-class
+#' @importMethodsFrom DBI dbIsValid
 #' @export
-setMethod('dbIsValid', 'PrestoResult', .dbIsValid)
+setMethod("dbIsValid", "PrestoResult", .dbIsValid)
